==> haskell-config-ini-0.2.7.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-ini
version:              0.2.7.0
visibility:           public
id:                   config-ini-0.2.7.0-AudsH5VNbYdIVcNfGBhYyh
key:                  config-ini-0.2.7.0-AudsH5VNbYdIVcNfGBhYyh
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  4a2e14e650016da7cedf89365f373104
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.7.0-AudsH5VNbYdIVcNfGBhYyh
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.7.0-3djLYUlnjlAJjkWgXBHMlu text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.7.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-ini
version:              0.2.7.0
visibility:           public
id:                   config-ini-0.2.7.0-3NWxeTP7pDCLUWZdF3xq2d
key:                  config-ini-0.2.7.0-3NWxeTP7pDCLUWZdF3xq2d
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  14abe63c08e7587a8da960fefd1bf0e1
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.7.0-3NWxeTP7pDCLUWZdF3xq2d
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.7.0-JdLotAX9gxvJ8pGS1qwpyC text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
